# -*- coding: utf-8 -*-
"""
If needed Copy/Paste this part into your own templatetags file
"""
import logging
from django import template
from django.db.models.query import QuerySet

register = template.Library()

__author__ = 'hbp'
__email__ = 'p.houben@cra.wallonie.be'
__copyright__ = 'Copyright 2021, Patrick Houben'
__license__ = 'GPLv3'
__date__ = '2021-07-07'
__version__ = '1.0'
__status__ = 'Development'

LOG = logging.getLogger(__name__)


@register.simple_tag
def get_verbose_field_name(objname, field_name):
    """
    Returns verbose_name for a field.
    """
    # Check wether objname is a QuerySet of directly the object instance!
    # QuerySet option should not be used since we do first() for each call in header
    if isinstance(objname, QuerySet):
        objcopy = objname
        instance = objcopy.first()
    else:
        instance = objname
    fname = instance._meta.get_field(field_name).verbose_name
    return fname.capitalize()


from django.http import HttpResponse, StreamingHttpResponse
from datetime import datetime



def response_with_mimetype_and_name(mimetype,
                                    name,
                                    extension=None,
                                    show_date=True,
                                    file_path=None,
                                    use_local_filesystem=False,
                                    full_mime=False):
    if extension is None:
        extension = mimetype
    if not full_mime:
        mimetype = "application/%s" % mimetype
    if file_path:
        try:
            if not use_local_filesystem:
                default_storage = get_storage_class()()
                wrapper = FileWrapper(default_storage.open(file_path))
                response = StreamingHttpResponse(
                    wrapper, content_type=mimetype)
                response['Content-Length'] = default_storage.size(file_path)
            else:
                wrapper = FileWrapper(open(file_path))
                response = StreamingHttpResponse(
                    wrapper, content_type=mimetype)
                response['Content-Length'] = os.path.getsize(file_path)
        except IOError:
            response = HttpResponseNotFound(
                "The requested file could not be found.")
    else:
        response = HttpResponse(content_type=mimetype)
    response['Content-Disposition'] = generate_content_disposition_header(
        name, extension, show_date)
    return response


def generate_content_disposition_header(name, extension, show_date=True):
    if name is None:
        return 'attachment;'
    if show_date:
        name = "%s-%s" % (name, datetime.now().strftime("%Y-%m-%d-%H-%M-%S"))
    return 'attachment; filename=%s.%s' % (name, extension)



# Generated by Django 4.0.5 on 2022-06-21 09:00

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('odk', '0003_remove_xform_modified_by_remove_xform_modified_on_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='xform',
            name='created_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='xform_created_by', to=settings.AUTH_USER_MODEL, verbose_name='Created by'),
        ),
        migrations.AlterField(
            model_name='xform',
            name='xml_content',
            field=models.TextField(blank=True, null=True, verbose_name='Content of XML form'),
        ),
    ]
